/*
 * See the NOTICE file distributed with this work for information
 * regarding copyright ownership.  This file is licensed
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.fabric3.spi.command;

import java.util.ArrayList;
import java.util.List;

/**
 * A set of commands to be executed in order on a service node. Commands are processed in three phases defined by {@link
 * Phase}.
 *
 * @version $Rev: 121 $ $Date: 2007-05-29 01:02:50 +0100 (Tue, 29 May 2007) $
 */
public class CommandSet {
    public enum Phase {
        FIRST,
        STANDARD,
        LAST
    }

    private List<Command> first = new ArrayList<Command>();
    private List<Command> standard = new ArrayList<Command>();
    private List<Command> last = new ArrayList<Command>();

    /**
     * Adds a command to the end of the command list.
     *
     * @param phase   the phase to run the command in
     * @param command the command to add
     */
    public void add(Phase phase, Command command) {
        if (phase == Phase.FIRST) {
            first.add(command);
        } else if (phase == Phase.LAST) {
            last.add(command);
        } else {
            standard.add(command);
        }
    }

    /**
     * Returns the ordered list of commands for the given phase.
     *
     * @param phase the phase to return the command list for
     * @return the ordered list of commands
     */
    public List<Command> getCommands(Phase phase) {
        if (phase == Phase.FIRST) {
            return first;
        } else if (phase == Phase.LAST) {
            return last;
        } else {
            return standard;
        }
    }
}
